@@ -4,7 +4,7 @@ package Tree::Simple::View::DHTML;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use parent 'Tree::Simple::View::HTML';
 
@@ -686,10 +686,15 @@ what browsers/platforms this supports, here is the list (of ones I have tested s
 This is also known to gracefully degrade in Netscape 4.7.2, in which it just shows
 the entire expanded tree.
 
-=head1 BUGS
+=head1 Repository
 
-None that I am aware of. Of course, if you find a bug, let me know, and I will be
-sure to fix it.
+L<https://github.com/ronsavage/Tree-Simple.git>
+
+=head1 SUPPORT
+
+Bugs should be reported via the CPAN bug tracker at
+
+L<https://github.com/ronsavage/Tree-Simple/issues>
 
 =head1 CODE COVERAGE
 
